@@ -1,14 +1,14 @@
 from os.path import join
 
-PREFIX          = "/usr"
-LIBDIR          = "/usr/lib"
-DATADIR         = "/usr/share"
-DOCDIR          = "/usr/share/doc/cherokee"
-LOCALEDIR       = "/usr/share/locale"
-WWWROOT         = "/var/www"
-SYSCONFDIR      = "/etc"
-LOCALSTATE      = "/var"
-VERSION         = "1.2.99b"
+PREFIX          = "/usr/local"
+LIBDIR          = "/usr/local/lib"
+DATADIR         = "/usr/local/share"
+DOCDIR          = "/usr/local/share/doc/cherokee"
+LOCALEDIR       = "/usr/local/share/locale"
+WWWROOT         = "/usr/local/var/www"
+SYSCONFDIR      = "/usr/local/etc"
+LOCALSTATE      = "/usr/local/var"
+VERSION         = "1.2.100"
 OWS_ENABLE      = '1'
 OWS_API_VERSION = '2'
 
