@@ -193,18 +193,20 @@ cherokee_handler_secdownload_new (cherokee_handler_t     **hdl,
 	re = strncasecmp (md5.buf, &conn->request.buf[1], 32);
 	if (re != 0) {
 #ifdef TRACE_ENABLED
-		cherokee_buffer_t tmp = CHEROKEE_BUF_INIT;
+		if (cherokee_trace_is_tracing()) {
+			cherokee_buffer_t tmp = CHEROKEE_BUF_INIT;
 
-		cherokee_buffer_add_str    (&tmp, "secret='");
-		cherokee_buffer_add_buffer (&tmp, &PROP_SECDOWN(props)->secret);
-		cherokee_buffer_add_str    (&tmp, "', path='");
-		cherokee_buffer_add        (&tmp, p, path_len);
-		cherokee_buffer_add_str    (&tmp, "', time='");
-		cherokee_buffer_add        (&tmp, time_s, 8);
-		cherokee_buffer_add_str    (&tmp, "'");
+			cherokee_buffer_add_str    (&tmp, "secret='");
+			cherokee_buffer_add_buffer (&tmp, &PROP_SECDOWN(props)->secret);
+			cherokee_buffer_add_str    (&tmp, "', path='");
+			cherokee_buffer_add        (&tmp, p, path_len);
+			cherokee_buffer_add_str    (&tmp, "', time='");
+			cherokee_buffer_add        (&tmp, time_s, 8);
+			cherokee_buffer_add_str    (&tmp, "'");
 
-		TRACE(ENTRIES, "MD5 (%s) didn't match (%s)\n", md5.buf, tmp.buf);
-		cherokee_buffer_mrproper(&tmp);
+			TRACE(ENTRIES, "MD5 (%s) didn't match (%s)\n", md5.buf, tmp.buf);
+			cherokee_buffer_mrproper(&tmp);
+		}
 #endif
 
 		cherokee_buffer_mrproper(&md5);
